# 1.0 Automated Tests

## 1.1 HLT001

Tutorial Section 1.0:

> `doorstop/cli/test/test_tutorial.py` (line 61)

*Parent links: TUT001, TUT002, TUT004, TUT008*

## 1.2 HLT002

Tutorial Section 2.0:

> `doorstop/cli/test/test_tutorial.py` (line 100)

*Parent links: TUT009, TUT010*

## 1.3 HLT003

Tutorial Section 3.0:

> `doorstop/cli/test/test_tutorial.py` (line 123)

*Parent links: TUT012, TUT013, TUT016*

## 1.4 HLT004

Tutorial Section 4.0:

> `doorstop/cli/test/test_tutorial.py` (line 145)

*Parent links: TUT015*

